# Bu Araç @keyiflerolsun tarafından | @KekikAkademi için yazılmıştır.

from requests import get

def sondakika_haberleri():
    istek = get("https://kolektifapi.kekikakademi.org/haber")
    return istek.json()["veri"]


# Bu araç @keyiflerolsun tarafından | @KekikAkademi için yazılmıştır.

from .CLI      import cikis_yap, hata_yakala

from flet      import FLET_APP, WEB_BROWSER
from flet      import app as flet
from flet.page import Page

from .Layouts import KekikFlet, Panel, Haberler
from os       import name as sistem

def ana_sayfa(sayfa:Page):
    KekikFlet(sayfa, "ntvHaber | @KekikAkademi")

    panel = Panel(sayfa)
    sayfa.add(panel)

    ntv = Haberler(sayfa, panel)
    sayfa.add(ntv)

# if __name__ == "__main__":
def basla():
    try:
        flet(target=ana_sayfa, view=FLET_APP if sistem != "nt" else WEB_BROWSER, port=1927, assets_dir="Assets")
        cikis_yap(False)
    except Exception as hata:
        hata_yakala(hata)


# Bu araç @keyiflerolsun tarafından | @KekikAkademi için yazılmıştır.

from setuptools import setup
from io         import open

setup(
    # ? Genel Bilgiler
    name         = "ntvHaber",
    version      = "0.5",
    url          = "https://github.com/keyiflerolsun/ntvHaber",
    description  = "NTV Son Dakika Haberleri",
    keywords     = ["ntvHaber", "KekikAkademi", "keyiflerolsun"],

    author       = "keyiflerolsun",
    author_email = "keyiflerolsun@gmail.com",

    license      = "GPLv3+",
    classifiers  = [
        "Development Status :: 5 - Production/Stable",
        "License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)",
        "Programming Language :: Python :: 3"
    ],

    # ? Paket Bilgileri
    packages         = ["ntvHaber"],
    python_requires  = ">=3.10",
    install_requires = [
        "pip",
        "setuptools",
        "wheel",
        "rich",
        "flet",
        "notify-py",
        "requests"
    ],

    # ? Konsoldan Çalıştırılabilir
    entry_points = {
        "console_scripts": [
            "ntvHaber = ntvHaber:basla",
        ]
    },

    # ? Masaüstü Paketi
    setup_requires = ["install_freedesktop"],
    data_files     = [
        ("share/applications",                ["org.kekikakademi.ntvHaber.desktop"]),
        ("share/appdata",                     ["org.kekikakademi.ntvHaber.appdata.xml"]),
        ("share/icons/hicolor/scalable/apps", ["ntvHaber/Assets/Logo.png"])
    ],

    # ? PyPI Bilgileri
    long_description_content_type = "text/markdown",
    long_description              = "".join(open("PyPi.md", encoding="utf-8").readlines()),
    include_package_data          = True
)